@@ -401,7 +401,8 @@ class ModRana(object):
 
         # check if logging to file should be enabled
         if self.get('loggingStatus', False):
-            modrana_log.log_manager.enable_log_file()
+            logCompression = self.get('compressLogFile', False)
+            modrana_log.log_manager.enable_log_file(compression=logCompression)
         else:
             modrana_log.log_manager.clear_early_log()
             # tell log manager log file is not needed and that it should
@@ -414,7 +415,8 @@ class ModRana(object):
     def _logFileCB(self, _key, _oldValue, newValue):
         """Convenience function turning the log file on or off"""
         if newValue:
-            modrana_log.log_manager.enable_log_file()
+            logCompression = self.get('compressLogFile', False)
+            modrana_log.log_manager.enable_log_file(compression=logCompression)
         else:
             modrana_log.log_manager.disable_log_file()
 
@@ -482,8 +484,10 @@ class ModRana(object):
             m.shutdown()
         self._saveOptions()
         time.sleep(2) # leave some times for threads to shut down
+        modrana_log.log_manager.disable_log_file()
         log.info("Shutdown complete")
 
+
     ## OPTIONS SETTING AND WATCHING ##
 
     def get(self, name, default=None, mode=None):
@@ -868,8 +872,20 @@ class ModRana(object):
 modrana = None
 dmod = None
 gui = None
-def start():
-    """This function is used when starting modRana with PyOtherSide"""
+def start(argv=None):
+    """This function is used when starting modRana with PyOtherSide.
+    When modRana is started from PyOtherSide there is no sys.argv,
+    so QML needs to pass it from its side.
+
+    :param list argv: arguments the program got on cli or arguments
+                      injected by QML
+    """
+    if not argv: argv = []
+    log.debug("argv from QML:\n%s", argv)
+    sys.argv = ["modrana.py"]
+    sys.argv.extend(argv)
+    log.debug("full argv:\n%s", sys.argv)
+
     global modrana
     global dmod
     global gui
