@@ -45,8 +45,8 @@ from core import geo
 from core import modrana_log
 
 import logging
-log = logging.getLogger("device.gui.qt5")
-qml_log = logging.getLogger("device.gui.qt5.qml")
+log = logging.getLogger("mod.gui.qt5")
+qml_log = logging.getLogger("mod.gui.qt5.qml")
 
 SEARCH_STATUS_PREFIX = "search:status:"
 SEARCH_RESULT_PREFIX = "search:result:"
@@ -87,7 +87,10 @@ class QMLGUI(GUIModule):
         size = (800, 480) # initial window size
 
         # register exit handler
-        pyotherside.atexit(self._shutdown)
+        #pyotherside.atexit(self._shutdown)
+        # FIXME: for some reason the exit handler is never
+        # called on Sailfish OS, so we use a onDestruction
+        # handler on the QML side to trigger shutdown
 
         # window state
         self._fullscreen = False
@@ -150,10 +153,9 @@ class QMLGUI(GUIModule):
     def _shutdown(self):
         """Called by PyOtherSide once the QML side is shutdown.
         """
-        self.log.info("shutting down")
+        self.log.info("Qt 5 GUI module shutting down")
         self.modrana.shutdown()
 
-
     def getIDString(self):
         return "Qt5"
 
@@ -303,6 +305,28 @@ class QMLGUI(GUIModule):
         except Exception:
             self.log.exception("adding tile download request failed")
 
+    def _getStartupValues(self):
+        """ Return a dict of values needed by the Qt 5 GUI right after startup.
+        By grouping the requested values in a single dict we reduce the number
+        of Python <-> QML roundtrips and also make it possible to more easily
+        get these values asynchronously (values arrive all at the same time,
+        not in random order at random time).
+
+        :returns: a dict gathering the requested values
+        :rtype dict:
+        """
+        values = {
+            "modRanaVersion" : self.getModRanaVersion(),
+            "constants" : self.getConstants(),
+            "showQuitButton": self.showQuitButton(),
+            "fullscreenOnly": self.modrana.dmod.fullscreenOnly(),
+            "shouldStartInFullscreen": self.shouldStartInFullscreen(),
+            "needsBackButton": self.modrana.dmod.needsBackButton(),
+            "needsPageBackground": self.modrana.dmod.needsPageBackground()
+        }
+        return values
+
+
 class Modules(object):
     """A class that provides access to modRana modules from the QML context,
        using the __getattr__ method so that QML can access all modules dynamically
